@@ -184,7 +184,6 @@
 #define HAVE_PERROR 1
 #define HAVE_POLL 1
 #define HAVE_POSIX_FALLOCATE 1
-#define HAVE_LINUX_FALLOC_H 1
 #define HAVE_FALLOC_PUNCH_HOLE_AND_KEEP_SIZE 1
 #define HAVE_PREAD 1
 #define HAVE_PAUSE_INSTRUCTION 1
@@ -219,6 +218,7 @@
 #define HAVE_SIGACTION 1
 /* #undef HAVE_SIGTHREADMASK */
 #define HAVE_SIGWAIT 1
+#define HAVE_SIGWAITINFO 1
 #define HAVE_SLEEP 1
 #define HAVE_SNPRINTF 1
 #define HAVE_STPCPY 1
@@ -380,6 +380,7 @@
 /* #undef HAVE_SVR3_SIGNALS */
 /* #undef HAVE_V7_SIGNALS */
 #define HAVE_ERR_remove_thread_state 1
+#define HAVE_X509_check_host 1
 
 /* #undef HAVE_SOLARIS_STYLE_GETHOST */
 
@@ -531,23 +532,23 @@
 #define MYSQL_DATADIR "/var/lib/mysql"
 #define DEFAULT_CHARSET_HOME "/usr"
 #define PLUGINDIR "/usr/lib/mysql/plugin"
-#define DEFAULT_SYSCONFDIR "/etc/mysql"
+#define DEFAULT_SYSCONFDIR "/etc"
 #define DEFAULT_TMPDIR P_tmpdir
 
 /* #undef SO_EXT */
 
 #define MYSQL_VERSION_MAJOR 10
-#define MYSQL_VERSION_MINOR 3
-#define MYSQL_VERSION_PATCH 16
+#define MYSQL_VERSION_MINOR 4
+#define MYSQL_VERSION_PATCH 6
 #define MYSQL_VERSION_EXTRA ""
 
 #define PACKAGE "mysql"
 #define PACKAGE_BUGREPORT ""
 #define PACKAGE_NAME "MySQL Server"
-#define PACKAGE_STRING "MySQL Server 10.3.16"
+#define PACKAGE_STRING "MySQL Server 10.4.6"
 #define PACKAGE_TARNAME "mysql"
-#define PACKAGE_VERSION "10.3.16"
-#define VERSION "10.3.16"
+#define PACKAGE_VERSION "10.4.6"
+#define VERSION "10.4.6"
 #define PROTOCOL_VERSION 10
 
 #define MALLOC_LIBRARY "system"
